#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 mmark
version:              0.0.7.6
visibility:           public
id:                   mmark-0.0.7.6-1BalUZ34RPf9qpPcFWl2cG
key:                  mmark-0.0.7.6-1BalUZ34RPf9qpPcFWl2cG
license:              BSD-3-Clause
maintainer:           Mark Karpov <markkarpov92@gmail.com>
author:               Mark Karpov <markkarpov92@gmail.com>
homepage:             https://github.com/mmark-md/mmark
synopsis:             Strict markdown processor for writers
description:          Strict markdown processor for writers.
category:             Text
abi:                  640dcdfd0444310e059cfe8ec53bee4f
exposed:              True
exposed-modules:      Text.MMark Text.MMark.Extension
hidden-modules:
    Text.MMark.Parser Text.MMark.Parser.Internal
    Text.MMark.Parser.Internal.Type Text.MMark.Render Text.MMark.Trans
    Text.MMark.Type Text.MMark.Util

import-dirs:          /usr/lib/ghc-9.6.6/site-local/mmark-0.0.7.6
library-dirs:         /usr/lib/ghc-9.6.6/site-local/mmark-0.0.7.6
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/mmark-0.0.7.6
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-mmark
hs-libraries:         HSmmark-0.0.7.6-1BalUZ34RPf9qpPcFWl2cG
depends:
    aeson-2.2.2.0-D5UyU4s17IF6uKIJTSur7o base-4.18.2.1
    case-insensitive-1.2.1.0-3KPQ2ag2hyl5eroFFm5hRO containers-0.6.7
    deepseq-1.4.8.1 dlist-1.0-Eygr3YxXU3I4OAzq8xpe04
    email-validate-2.3.2.21-4E0HTSoVKimGdWVKmz6uBZ
    foldl-1.4.18-BBNInaHQ78L2JuF85AJif2
    hashable-1.4.7.0-4qZi9v5WFMZ3p1WVFpevAr
    html-entity-map-0.1.0.0-5vfeZzRdjWNJzkPCI282Z9
    lucid-2.11.20250303-CETuQDQwGuEEIY3z2GWDZ9
    megaparsec-9.7.1-JZM7B7kDfd1CjE8IdXUm1J
    microlens-0.4.14.0-IP2Uuhm3qTnDhkfYobH8B3
    microlens-th-0.4.3.17-1JCZcjTuCbDB2Q9keDntvT
    modern-uri-0.3.6.1-IHTNES9GYHZDgCfoMDFb3t mtl-2.3.1
    parser-combinators-1.3.1-8aQ8dKOwDVmFxT1S1WvW6m text-2.0.2
    text-metrics-0.3.3-DmVjojWjJokEEJUssChD6S
    unordered-containers-0.2.20.1-4LGdNZVNGNC9SVCFAuU8Mp
    yaml-0.11.11.2-JaCnvXVwHr1DIN7Fv30Aj1

haddock-interfaces:   /usr/share/doc/haskell-mmark/html/mmark.haddock
haddock-html:         /usr/share/doc/haskell-mmark/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

